import React, { useEffect, useState } from 'react';
import axios from 'axios';
import Alert from 'react-bootstrap/Alert';
import Badge from 'react-bootstrap/Badge';

import {readPbf} from '../utils/gtfs-rt-utils';
import Map from '../components/map/map';

import config from '../config';


export default function VehiclePositions() {

    const [rry, setRry] = useState([]);
    const [entityCount, setEntityCount] = useState(0);
    const [entityVehiclePositionCount, setEntityVehiclePositionCount] = useState(0);

    
    /*get data*/
    const getData = async () => {

        try {
            /*TODO handle errors: https://www.valentinog.com/blog/await-react/*/
	    //TODO Make fields available via configuration!
	    const optns = { responseType: 'arraybuffer'	};
            const address = `${config.API}`;
	    //console.log('getData() address: ' + address );

            const res = await axios.get(address, optns);

            if(res.data){
                ////console.log('getRry() res available');
		const rry = readPbf(res.data);
		const rryLngth= rry.length;
                //console.log('getRry() rryLngh: ' + rryLngth);
		setEntityCount(rryLngth);

		const rryEVP = new Array();
		rry.forEach(entity => {
		    const entityVehiclePosition = entity.vehicle;
		    if (entityVehiclePosition !== null && entityVehiclePosition !== undefined) {
			const oEVP = {};
			const trip = entityVehiclePosition.trip;
			if (trip !== null && trip !== undefined) {
			    oEVP.trip_id = trip.trip_id;
			    oEVP.route_id = trip.route_id;
			    const position = entityVehiclePosition.position;
			    if (position !== null && position !== undefined) {
				oEVP.latitude = position.latitude;
				oEVP.longitude = position.longitude;
				rryEVP.push(oEVP);
			    }
			}
		    }
		});
		const rryEVPLngth = rryEVP.length;
                //console.log('getRry() rryEVPLength: ' + rryEVPLngth);

		setEntityVehiclePositionCount(rryEVPLngth);

		setRry(rryEVP);

	    }else{
                console.error('getRry() res NOT available');
	    }

        } catch (err) {
            console.error('err.message: ' + err.message);
	    setRry([]);
        }
	//////console.log('getData() done.');
    };

    useEffect(()=>{
	//initial call
	getData();

	const intervalCall=setInterval(()=>{
	    getData();
	}, 10000);
	return ()=>{
	    clearInterval(intervalCall);
	};
    },[]);

    if (rry.length > 0) {
	/*return a React element*/
    return (
	<>
		<Badge bg="secondary">
		    abs entity count: {entityCount}&nbsp;
		</Badge>
		&nbsp;
		<Badge bg="secondary">
		    abs VehiclePosition count: {entityVehiclePositionCount}&nbsp;
		</Badge>
		&nbsp;
	    <Map messages={rry}/>
	</>
    );
    } else {
	return (
	    <Alert variant={'secondary'} onClose={() => setShow(false)} dismissible>
		<Badge bg="secondary">VehiclePostion</Badge> entities loading...
            </Alert>

	);
    }
};
